/*
 * Copyright (C) 2003-2005 Christian Siefkes <christian@siefkes.net>
 * Parts of this code are Copyright (C) 2001-2002 by MUNDWERK AG.
 * Re-released under GNU GPL with permission of MUNDWERK AG.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package net.siefkes.nlstego.predict;

import java.io.Serializable;
import java.util.SortedMap;

/**
 * Abstract class for storing information on the items predicted
 * in a certain state. <p>
 * Created (17.09.2001 16:08:00).<p>
 *
 * @author Christian Siefkes
 * @version $Revision: 1.4 $, $Date: 2005/07/12 17:02:17 $, $Author: siefkes $
 */
abstract class FetchStatsEntry implements Serializable {

/**
 * Creates a new instance.<p>
 * Created (17.09.2001 16:08:57) by Christian Siefkes.<p>
 */
protected FetchStatsEntry() {
    super();
} // constructor

/**
 * Adds a request of an item.<p>
 * Created (17.09.2001 16:15:49) by Christian Siefkes.<p>
 *
 * @param key the unique ID of the item
 */
abstract void add(final Integer key);

/**
 * Returns the most probably items as well as their probabilities
 * (List of FetchStatsResult's).<p>
 * Created (18.09.2001 15:47:31) by Christian Siefkes.<p>
 *
 * @param number the number of results to return, >0
 * @param minAccesses how many accesses an item must have had to be
 * considered worth of predicting, >= 0
 * @param sessionID the ID of the current session (must be unique among all
 * sessions parallel in progress)
 * @return a SortedMap containing mapped keys as keys and FetchStatsResult's
 * as values. The size of the map is max
 * (<code>number</code>, all documents stored in this entry that had at least
 * <code>minAccesses</code>)
 */
abstract SortedMap<Integer, FetchStatsResult> predict(final int number,
        final int minAccesses, final int sessionID);
} // class

