/*
 * Copyright (C) 2003-2005 Christian Siefkes <christian@siefkes.net>
 * Parts of this code are Copyright (C) 2001-2002 by MUNDWERK AG.
 * Re-released under GNU GPL with permission of MUNDWERK AG.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package net.siefkes.nlstego.predict;

import java.io.Serializable;

/**
 * Wrapper for the data returned by <code>FetchStats[Entry].predict</code>. <p>
 * Created (18.09.2001 15:26:00).<p>
 *
 * @author Christian Siefkes
 * @version $Revision: 1.4 $, $Date: 2005/07/12 17:02:17 $, $Author: siefkes $
 */
final class FetchStatsResult implements Serializable {

    /**
     * A constant with the name of this class. <p>
     * Created (30.10.2001 10:47:54) by Christian Siefkes.<p>
     */
    private static final String NAME = "FetchStatsResult";

    /**
     * The value fetching this document (not necessarily a probability). <p>
     * Created (18.09.2001 15:33:26) by Christian Siefkes.<p>
     */
    private double value;

    /**
     * The unique ID of this document. <p>
     * Created (29.10.2001 13:12:45) by Christian Siefkes.<p>
     */
    private final int mappedKey;

    /**
     * The ID of the current session (unique among all sessions parallel
     * in progress). <p>
     * Created (22.11.2001 09:34:03) by Christian Siefkes.<p>
     */
    private final int sessionID;

/**
 * Creates a new instance. <p>
 * Created (18.09.2001 15:27:38) by Christian Siefkes.<p>
 *
 * @param theMappedKey the unique ID of this document
 * @param theValue the value of fetching this document
 * @param theSessionID the ID of the current session (must be unique among all
 * sessions parallel in progress)
 */
FetchStatsResult(final int theMappedKey, final double theValue,
        final int theSessionID) {
    super();

    mappedKey = theMappedKey;
    value = theValue;
    sessionID = theSessionID;
} // constructor

/**
 * A standard <code>get*()</code>. <p>
 * Created (29.10.2001 13:13:04) by Christian Siefkes.<p>
 *
 * @return the value of the attribute
 */
int getMappedKey() {
    return mappedKey;
} // method

/**
 * A standard <code>get*()</code>. <p>
 * Created (22.11.2001 09:35:36) by Christian Siefkes.<p>
 *
 * @return the value of the attribute
 */
int getSessionID() {
    return sessionID;
} // method

/**
 * A standard <code>get*()</code>. <p>
 * Created (18.09.2001 15:39:01) by Christian Siefkes.<p>
 *
 * @return the value of the attribute
 */
double getValue() {
    return value;
} // method

/**
 * A standard <code>set*()</code>. <p>
 * Created (02.10.2001 18:08:17) by Christian Siefkes.<p>
 *
 * @param newValue the new value of the attribute
 */
synchronized void setValue(final double newValue) {
    value = newValue;
} // method

/**
 * Returns a String that represents the value of this object. <p>
 * Created (30.10.2001 10:46:50) by Christian Siefkes.<p>
 *
 * @return a string representation of the receiver
 */
public String toString() {
    return "[" + NAME + ": mapped key=" + getMappedKey()
        + ", value=" + getValue()
        + ", session ID=" + getSessionID() + "]";
} // method
} // class
