/*
 * Copyright (C) 2003-2005 Christian Siefkes <christian@siefkes.net>.
 * Parts of this code are Copyright (C) 2001-2002 by MUNDWERK AG.
 * Re-released under GNU GPL with permission of MUNDWERK AG.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package net.siefkes.nlstego.predict;

import java.io.Serializable;

/**
 * A wrapper around the number of times an item was fetched.
 * Used by FetchStatsEntry.<p>
 * Created (17.09.2001 16:35:49).<p>
 *
 * @author Christian Siefkes
 * @version $Revision: 1.5 $, $Date: 2005/07/12 17:02:17 $, $Author: siefkes $
 */
final class FetchStatsSubEntry implements Serializable {
    /**
     * How many times was this document fetched?<p>
     * Created (18.09.2001 11:00:02) by Christian Siefkes.<p>
     */
    private int accesses = 0;

    /**
     * Creates a new instance, setting the number of accesses to
     * <code>1</code>.<p>
     * Created (17.09.2001 16:39:19) by Christian Siefkes.<p>
     */
    FetchStatsSubEntry() {
        super();
        setAccesses(1);
    } // constructor

    /**
     * A standard <code>get*()</code>.<p>
     * Created (17.09.2001 16:44:49) by Christian Siefkes.<p>
     *
     * @return the value of the attribute
     */
    int getAccesses() {
        return accesses;
    } // method

    /**
     * A standard <code>set*()</code>.<p>
     * Created (17.09.2001 16:46:51) by Christian Siefkes.<p>
     *
     * @param newAccesses the new value of the attribute
     */
    synchronized void setAccesses(final int newAccesses) {
        accesses = newAccesses;
    } // method

    /**
     * Returns a String representation of this object.
     *
     * @return a string representation of this object
     */
    public String toString() {
        return "[FetchStatsSubEntry: number of accesses=" + getAccesses()
            + "]";
    }
} // class
