/*
 * Copyright (C) 2003-2005 Christian Siefkes <christian@siefkes.net>
 * Parts of this code are Copyright (C) 2001-2002 by MUNDWERK AG.
 * Re-released under GNU GPL with permission of MUNDWERK AG.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package net.siefkes.nlstego.predict;

import java.io.Serializable;

/**
 * Wrapper for a predicted token. Contains the token and its probability. <p>
 *
 * @author Christian Siefkes
 * @version $Revision: 1.7 $, $Date: 2005/07/12 17:02:17 $, $Author: siefkes $
 */
public class PredictedToken implements Serializable {

    /**
     * The probability of this token. <p>
     */
    private final double probability;

    /**
     * The String representation of this token.
     */
    private final String token;

    /**
     * Creates a new instance. <p>
     *
     * @param theToken the String representation of this token
     * @param theProbability the probability of this token
     */
    public PredictedToken(final String theToken, final double theProbability) {
        super();

        token = theToken;
        probability = theProbability;
    }

    /**
     * Returns a String that represents the value of this object. <p>
     * Created (30.10.2001 10:46:50) by Christian Siefkes.<p>
     *
     * @return a string representation of the receiver
     */
    public final String toString() {
        return "\"" + getToken() + "\"/" + getProbability();
    }

    /**
     * Returns the probability of this token.
     *
     * @return the probability
     */
    public final double getProbability() {
        return probability;
    }

    /**
     * Returns the String representation of this token.
     *
     * @return the String representation
     */
    public final String getToken() {
        return token;
    }
}
