/*
 * Copyright (C) 2005 Christian Siefkes <christian@siefkes.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package net.siefkes.nlstego.predict;

/**
 * This interface filters which predictions should be stored in the stateless
 * (global) model. It can be implemented to discard predictions that are
 * unnecessary or unsuitable for the stateless model.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2005/07/28 15:03:09 $, $Author: siefkes $
 */
public interface StatelessFilter {

    /**
     * Whether a key should be accepted for the stateless model.
     * @param key the key to check
     * @return <code>true</code> if this key should be considered by stateless
     * model; <code>false</code> otherwise
     */
    boolean acceptForStateless(final String key);

}
